@@ -7,7 +7,6 @@
 #include "filterlog.h"
 
 #include "mailcommon_debug.h"
-#include "messagecomposer/util.h"
 
 #include <QFile>
 #include <QTime>
@@ -190,3 +189,5 @@ QString FilterLog::recode(const QString &plain)
 {
     return plain.toHtmlEscaped();
 }
+
+#include "moc_filterlog.cpp"
