@@ -50,13 +50,13 @@ public:
     /**
      * Returns whether the filter manager is in a usable state.
      */
-    Q_REQUIRED_RESULT bool isValid() const;
+    [[nodiscard]] bool isValid() const;
 
     /**
      * Checks for existing filters with the @p name and extend the
      * "name" to "name (i)" until no match is found for i=1..n
      */
-    Q_REQUIRED_RESULT QString createUniqueFilterName(const QString &name) const;
+    [[nodiscard]] QString createUniqueFilterName(const QString &name) const;
 
     /**
      * Returns the global filter action dictionary.
@@ -133,7 +133,7 @@ public:
      * write everything back into the configuration. The filter manager
      * takes ownership of the filters in the list.
      */
-    void appendFilters(const QVector<MailCommon::MailFilter *> &filters, bool replaceIfNameExists = false);
+    void appendFilters(const QList<MailCommon::MailFilter *> &filters, bool replaceIfNameExists = false);
 
     /**
      * Removes the given @p filter from the list.
@@ -145,12 +145,12 @@ public:
      * Replace the list of filters of the filter manager with the given list of @p filters.
      * The manager takes ownership of the filters.
      */
-    void setFilters(const QVector<MailCommon::MailFilter *> &filters);
+    void setFilters(const QList<MailCommon::MailFilter *> &filters);
 
     /**
      * Returns the filter list of the manager.
      */
-    QVector<MailCommon::MailFilter *> filters() const;
+    QList<MailCommon::MailFilter *> filters() const;
 
     /**
      * Should be called at the beginning of an filter list update.
@@ -162,20 +162,20 @@ public:
      */
     void endUpdate();
 
-    QMap<QUrl, QString> tagList() const;
+    [[nodiscard]] QMap<QUrl, QString> tagList() const;
 
-    bool initialized() const;
+    [[nodiscard]] bool initialized() const;
 
     void cleanup();
 private Q_SLOTS:
-    void slotServerStateChanged(Akonadi::ServerManager::State);
-    void slotFinishedTagListing(KJob *);
-    void slotReadConfig();
-    void updateTagList();
+    MAILCOMMON_NO_EXPORT void slotServerStateChanged(Akonadi::ServerManager::State);
+    MAILCOMMON_NO_EXPORT void slotFinishedTagListing(KJob *);
+    MAILCOMMON_NO_EXPORT void slotReadConfig();
+    MAILCOMMON_NO_EXPORT void updateTagList();
 
-    void slotTagAdded(const Akonadi::Tag &);
-    void slotTagChanged(const Akonadi::Tag &);
-    void slotTagRemoved(const Akonadi::Tag &);
+    MAILCOMMON_NO_EXPORT void slotTagAdded(const Akonadi::Tag &);
+    MAILCOMMON_NO_EXPORT void slotTagChanged(const Akonadi::Tag &);
+    MAILCOMMON_NO_EXPORT void slotTagRemoved(const Akonadi::Tag &);
 
 Q_SIGNALS:
     /**
@@ -188,10 +188,9 @@ Q_SIGNALS:
     void loadingFiltersDone();
 
 private:
-    FilterManager();
+    MAILCOMMON_NO_EXPORT FilterManager();
 
     class FilterManagerPrivate;
     FilterManagerPrivate *const d;
 };
 }
-
