@@ -19,8 +19,8 @@
 #include <QApplication>
 #include <util/resourcereadconfigfile.h>
 
-#include <KIdentityManagement/Identity>
-#include <KIdentityManagement/IdentityManager>
+#include <KIdentityManagementCore/Identity>
+#include <KIdentityManagementCore/IdentityManager>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -165,7 +165,7 @@ void Kernel::initFolders()
     findCreateDefaultCollection(Akonadi::SpecialMailCollections::Trash);
     findCreateDefaultCollection(Akonadi::SpecialMailCollections::Templates);
 
-    auto *job = new Akonadi::SpecialMailCollectionsDiscoveryJob(this);
+    auto job = new Akonadi::SpecialMailCollectionsDiscoveryJob(this);
     job->start();
     // we don't connect to the job directly: it will register stuff into SpecialMailCollections, which will Q_EMIT signals.
 }
@@ -179,7 +179,7 @@ void Kernel::findCreateDefaultCollection(Akonadi::SpecialMailCollections::Type t
             emergencyExit(i18n("You do not have read/write permission to your inbox folder."));
         }
     } else {
-        auto *job = new Akonadi::SpecialMailCollectionsRequestJob(this);
+        auto job = new Akonadi::SpecialMailCollectionsRequestJob(this);
 
         connect(job, &Akonadi::SpecialMailCollectionsRequestJob::result, this, &Kernel::createDefaultCollectionDone);
 
@@ -194,7 +194,7 @@ void Kernel::createDefaultCollectionDone(KJob *job)
         return;
     }
 
-    auto *requestJob = qobject_cast<Akonadi::SpecialMailCollectionsRequestJob *>(job);
+    auto requestJob = qobject_cast<Akonadi::SpecialMailCollectionsRequestJob *>(job);
 
     const Akonadi::Collection col = requestJob->collection();
     if (!(col.rights() & Akonadi::Collection::AllRights)) {
@@ -269,9 +269,9 @@ bool Kernel::folderIsDrafts(const Akonadi::Collection &col)
     }
 
     // search the identities if the folder matches the drafts-folder
-    const KIdentityManagement::IdentityManager *im = KernelIf->identityManager();
-    KIdentityManagement::IdentityManager::ConstIterator end(im->end());
-    for (KIdentityManagement::IdentityManager::ConstIterator it = im->begin(); it != end; ++it) {
+    const KIdentityManagementCore::IdentityManager *im = KernelIf->identityManager();
+    KIdentityManagementCore::IdentityManager::ConstIterator end(im->end());
+    for (KIdentityManagementCore::IdentityManager::ConstIterator it = im->begin(); it != end; ++it) {
         if ((*it).drafts() == idString) {
             return true;
         }
@@ -290,9 +290,9 @@ bool Kernel::folderIsTemplates(const Akonadi::Collection &col)
     }
 
     // search the identities if the folder matches the templates-folder
-    const KIdentityManagement::IdentityManager *im = KernelIf->identityManager();
-    KIdentityManagement::IdentityManager::ConstIterator end(im->end());
-    for (KIdentityManagement::IdentityManager::ConstIterator it = im->begin(); it != end; ++it) {
+    const KIdentityManagementCore::IdentityManager *im = KernelIf->identityManager();
+    KIdentityManagementCore::IdentityManager::ConstIterator end(im->end());
+    for (KIdentityManagementCore::IdentityManager::ConstIterator it = im->begin(); it != end; ++it) {
         if ((*it).templates() == idString) {
             return true;
         }
@@ -337,9 +337,9 @@ bool Kernel::folderIsSentMailFolder(const Akonadi::Collection &col)
     }
 
     // search the identities if the folder matches the sent-folder
-    const KIdentityManagement::IdentityManager *im = KernelIf->identityManager();
-    KIdentityManagement::IdentityManager::ConstIterator end(im->end());
-    for (KIdentityManagement::IdentityManager::ConstIterator it = im->begin(); it != end; ++it) {
+    const KIdentityManagementCore::IdentityManager *im = KernelIf->identityManager();
+    KIdentityManagementCore::IdentityManager::ConstIterator end(im->end());
+    for (KIdentityManagementCore::IdentityManager::ConstIterator it = im->begin(); it != end; ++it) {
         if ((*it).fcc() == idString) {
             return true;
         }
@@ -387,3 +387,5 @@ QMap<QString, Akonadi::Collection::Id> Kernel::pop3ResourceTargetCollection()
     return mapIdentifierCollectionId;
 }
 }
+
+#include "moc_mailkernel.cpp"
