@@ -386,14 +386,3 @@ void SearchPattern::generateSieveScript(QStringList &requiresModules, QString &c
         (*it)->generateSieveScript(requiresModules, code);
     }
 }
-
-// Needed for MSVC 2010, as it seems to not implicit cast for a pointer anymore
-#ifdef _MSC_VER
-namespace MailCommon
-{
-uint qHash(SearchRule::Ptr sr)
-{
-    return ::qHash(sr.get());
-}
-}
-#endif
