@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -254,7 +254,7 @@ protected:
 private:
     static Function configValueToFunc(const char *);
     static QString functionToString(Function);
-    QString conditionToString(Function function);
+    MAILCOMMON_NO_EXPORT QString conditionToString(Function function);
 
     QByteArray mField;
     Function mFunction;
